@@ -180,8 +180,9 @@ QTime KHolidays::SunRiseSet::utcSunrise(const QDate &date, double latitude, doub
     double hourAngle = calcHourAngleSunrise(latitude, solarDec);
     double delta = longitude + radToDeg(hourAngle);
     QTime timeUTC(0, 0);
-    if (isnan(delta))
+    if (std::isnan(delta)) {
         return timeUTC;
+    }
     timeUTC = timeUTC.addSecs((720 - (4.0 * delta) - eqTime) * 60);
     return QTime(timeUTC.hour(),
                  timeUTC.second() > 29 ? timeUTC.minute() + 1 : timeUTC.minute(),
@@ -199,8 +200,9 @@ QTime KHolidays::SunRiseSet::utcSunset(const QDate &date, double latitude, doubl
     double hourAngle = -calcHourAngleSunrise(latitude, solarDec);
     double delta = longitude + radToDeg(hourAngle);
     QTime timeUTC(0, 0);
-    if (isnan(delta))
+    if (std::isnan(delta)) {
         return timeUTC;
+    }
     timeUTC = timeUTC.addSecs((720 - (4.0 * delta) - eqTime) * 60);
     return QTime(timeUTC.hour(),
                  timeUTC.second() > 29 ? timeUTC.minute() + 1 : timeUTC.minute(),
